import { DeepPartial } from '@azure-tools/codegen';
import { Expression, ExpressionOrLiteral, LiteralExpression } from './expression';
import { Namespace } from './namespace';
import { Parameter } from './parameter';
import { Property } from './property';
import { TypeDeclaration } from './type-declaration';
import { Variable } from './variable';
import { Dictionary } from '@azure-tools/linq';
import { IInterface } from './type-container';
export declare class ClassType implements TypeDeclaration {
    private name;
    get fullName(): string;
    private namespace;
    constructor(namespace: Namespace | string, name: string);
    get declaration(): string;
    toString(): string;
    new(...parameters: Array<ExpressionOrLiteral>): Expression;
    Cast(expression: ExpressionOrLiteral): Expression;
}
export declare class EnumType implements TypeDeclaration {
    private namespace;
    private name;
    constructor(namespace: Namespace, name: string);
    get declaration(): string;
    member(enumMember: string): Expression;
    get definition(): string;
    toString(): string;
    newProperty(name: string, objectInitializer?: DeepPartial<Property>): Property;
    newParameter(name: string, objectInitializer?: DeepPartial<Parameter>): Parameter;
    withMembers<T>(): T & EnumType;
}
export interface Index<T> {
    [key: number]: T;
}
export declare const None: Namespace;
export declare const System: Namespace & {
    Threading: Namespace & {
        CancellationToken: ClassType;
        CancellationTokenSource: ClassType;
        Tasks: Namespace & {
            Task(taskType?: TypeDeclaration | undefined): TypeDeclaration;
        };
    };
    Convert: ClassType & {
        ToBase64String: (expression: ExpressionOrLiteral) => Expression;
    };
    Linq: Namespace & {
        Enumerable: ClassType & {
            ToArray: (source: ExpressionOrLiteral) => Expression;
            Select: (source: ExpressionOrLiteral, selector: string) => Expression;
            Where: (source: ExpressionOrLiteral, predicate: string) => Expression;
            ToDictionary: (source: ExpressionOrLiteral, keySelector: string, valueSelector: string) => Expression;
            Empty: (type: TypeDeclaration) => Expression;
        };
    };
    Object: ClassType;
    String: ClassType & {
        Empty: LiteralExpression;
        IsNullOrEmpty: (expression: ExpressionOrLiteral) => Expression;
        IsNullOrWhitespace: (expression: ExpressionOrLiteral) => Expression;
        /** @description Binds a Variable to the known instance methods of this type */
        $BindTo: ($instance: Variable) => Variable & {
            Substring: (start: ExpressionOrLiteral, end?: string | Expression | undefined) => string;
        };
    };
    StringComparison: EnumType;
    DateTime: ClassType;
    DateTimeKind: ClassType & {
        Utc: LiteralExpression;
    };
    EventArgs: ClassType;
    Exception: ClassType;
    OperationCanceledException: ClassType;
    AggregateException: ClassType;
    TimeSpan: ClassType;
    Type: ClassType;
    Uri: ClassType;
    IFormatProvider: ClassType;
    Xml: Namespace & {
        Linq: Namespace & {
            XElement: ClassType;
            XAttribute: ClassType;
        };
    };
    IO: Namespace & {
        Stream: ClassType;
    };
    Text: Namespace & {
        Encoding: ClassType & {
            UTF8: LiteralExpression;
        };
        RegularExpressions: Namespace & {
            Regex: ClassType;
        };
    };
    Net: Namespace & {
        WebProxy: ClassType;
        Http: Namespace & {
            HttpRequestMessage: ClassType;
            HttpClient: ClassType;
            HttpClientHandler: ClassType;
            HttpResponseMessage: ClassType;
            Headers: Namespace & {
                MediaTypeHeaderValue: ClassType & {
                    Parse: (header: string) => Expression;
                };
                HttpHeaders: ClassType;
                HttpResponseHeaders: ClassType;
            };
            StringContent: ClassType;
            StreamContent: ClassType;
            MultipartFormDataContent: ClassType;
        };
        HttpStatusCode: ClassType & Dictionary<LiteralExpression> & Index<LiteralExpression>;
    };
    Collections: Namespace & {
        Hashtable: ClassType;
        IDictionary: ClassType;
        IEnumerator: ClassType;
        Generic: Namespace & {
            Dictionary(keyType: TypeDeclaration, valueType: TypeDeclaration): ClassType;
            IDictionary(keyType: TypeDeclaration, valueType: TypeDeclaration): IInterface;
            KeyValuePair(keyType: TypeDeclaration, valueType: TypeDeclaration): ClassType;
            IEnumerable(type: TypeDeclaration): ClassType;
            HashSet(type: TypeDeclaration): ClassType;
            IEnumerator(type: TypeDeclaration): ClassType;
            ICollection(type: TypeDeclaration): ClassType;
        };
    };
    Action(...actionParameters: TypeDeclaration[]): ClassType;
    Func(...funcParameters: TypeDeclaration[]): ClassType;
};
export declare const dotnet: {
    Unknown: ClassType;
    ToDo: ClassType;
    Void: ClassType;
    String: ClassType;
    StringArray: ClassType;
    Int: ClassType;
    Long: ClassType;
    Double: ClassType;
    Float: ClassType;
    Binary: ClassType;
    Bool: ClassType;
    Object: ClassType;
    Dynamic: ClassType;
    ThisObject: ClassType;
    Var: ClassType;
    True: LiteralExpression;
    False: LiteralExpression;
    Null: LiteralExpression;
    This: LiteralExpression;
    Array: (type: TypeDeclaration) => {
        declaration: string;
    };
};
//# sourceMappingURL=dotnet.d.ts.map