"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
const codegen_1 = require("@azure-tools/codegen");
const access_modifier_1 = require("./access-modifier");
const doc_comments_1 = require("./doc-comments");
const expression_1 = require("./expression");
const variable_1 = require("./variable");
const linq_1 = require("@azure-tools/linq");
/** represents a field in a Class */
class Field extends variable_1.Variable {
    constructor(name, type, objectInitializer) {
        super();
        this.name = name;
        this.type = type;
        this['new'] = access_modifier_1.Modifier.None;
        this.access = access_modifier_1.Access.Public;
        this['static'] = access_modifier_1.Modifier.None;
        this['readonly'] = access_modifier_1.Modifier.None;
        this.volitile = access_modifier_1.Modifier.None;
        this.attributes = new Array();
        this.description = '';
        this.apply(objectInitializer);
        if (!this.description.trim()) {
            this.description = '';
        }
    }
    get attributeDeclaration() {
        return linq_1.length(this.attributes) > 0 ? `${this.attributes.joinWith(each => `${each.value}`, codegen_1.EOL)}${codegen_1.EOL}` : '';
    }
    get declaration() {
        const initializer = this.initialValue ? ` = ${expression_1.valueOf(this.initialValue)}` : '';
        return `${codegen_1.docComment(doc_comments_1.xmlize('summary', this.description))}
${this.attributeDeclaration}${this.new}${this.access} ${this.static} ${this.readonly} ${this.volitile} ${this.type.declaration} ${this.name}${initializer};`.slim();
    }
    get value() {
        return `${this.name}`;
    }
    assign(expression) {
        if (this.readonly) {
            throw new Error('Readonly Field can not be assigned');
        }
        return `${this.name} = ${expression_1.valueOf(expression)};`;
    }
    assignPrivate(expression) {
        if (this.readonly) {
            throw new Error('Readonly Field can not be assigned');
        }
        return this.assign(expression);
    }
    get declarationExpression() {
        return this;
    }
    get declarationStatement() {
        throw new Error('Property can not be a declaration statement');
    }
}
exports.Field = Field;
//# sourceMappingURL=field.js.map